@@ -5,7 +5,7 @@ use Mojo::File qw(path);
 use Mojo::JSON qw(decode_json);
 use Carp;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 has client_email => undef;
 has expires_in   => 3600;
@@ -91,7 +91,7 @@ Mojo::JWT::Google - Service Account tokens
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
@@ -142,7 +142,7 @@ need to impersonate.
 
 
 To authenticate, send a post request to https://www.googleapis.com/oauth2/v4/token, 
-your Mojo::JWT::Google's as_form_data method.
+with your Mojo::JWT::Google's as_form_data method as the payload.
 
   $ua->post('https://www.googleapis.com/oauth2/v4/token', form => $gjwt->as_form_data);
 
